import type { VxeGridProps } from '#/adapter/vxe-table';
import type { DescItem } from '#/components/description';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'equId',
    label: '设备名称'
  },
  {
    component: 'RangePicker',
    fieldName: 'changeDate',
    label: '变更日期'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 100,
    fixed: 'left',
    slots: { default: 'equName' }
  },
  {
    title: '变更日期',
    field: 'changeDate',
    sortable: true,
    minWidth: 180
  },
  {
    title: '变更前',
    field: 'beforeChange',
    sortable: true,
    slots: {
      default: ({ row }) => {
        return renderDict(row.beforeChange, DictEnum.SYS_EQU_STATUS);
      }
    },
    minWidth: 80,
    fixed: 'left'
  },
  {
    title: '变更后',
    field: 'afterChange',
    sortable: true,
    slots: {
      default: ({ row }) => {
        return renderDict(row.afterChange, DictEnum.SYS_EQU_STATUS);
      }
    },
    minWidth: 80,
    fixed: 'left'
  },

  {
    title: '变更描述',
    field: 'changeDesc',
    minWidth: 120
  },
  {
    title: '变更人',
    field: 'changeUserName',
    minWidth: 120
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'equStatuId'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'equId',
    label: '设备id'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'changeDate',
    label: '变更日期'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'userDept',
    label: '变更人部门',
    help: `变更人员所属部门`
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      allowClear: true,
      showSearch: true,
      getPopupContainer
    },
    fieldName: 'changeUser',
    label: '变更人',
    help: `设备状态变更操作人员`
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.SYS_EQU_STATUS),
      optionType: 'button'
    },
    fieldName: 'beforeChange',
    label: '变更前',
    help: '设备变更前状态'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.SYS_EQU_STATUS),
      optionType: 'button'
    },
    fieldName: 'afterChange',
    label: '变更后',
    help: '设备变更后状态'
  },
  {
    component: 'Textarea',
    fieldName: 'changeDesc',
    label: '变更描述'
  }
];

export const descSchema: DescItem[] = [
  {
    field: 'equName',
    label: '设备名称'
  },
  {
    field: 'beforeChange',
    label: '变更前',
    render(value) {
      return renderDict(value, DictEnum.SYS_EQU_STATUS);
    }
  },
  {
    field: 'afterChange',
    label: '变更后',
    render(value) {
      return renderDict(value, DictEnum.SYS_EQU_STATUS);
    }
  },
  {
    field: 'changeDate',
    label: '变更日期'
  },
  {
    field: 'changeDesc',
    label: '变更描述'
  },
  {
    field: 'changeUserName',
    label: '变更人'
  }
];
